@@ -13,7 +13,7 @@ use Socket qw(inet_ntoa AF_INET IPPROTO_TCP);
 my $AF_INET6 = eval { Socket::AF_INET6() };
 my $NI_NUMERICHOST = eval { Socket::NI_NUMERICHOST() };
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 our @ISA;
 
 my $HAVE_IO_Socket_IP = 0;
@@ -94,7 +94,6 @@ $asn->prepare("
     }
 ");
 my $snmpasn = $asn->find('PDU');
-
 ########################################################
 # End Variables
 ########################################################
@@ -457,7 +456,7 @@ sub varbinds {
 }
 
 sub error {
-    return($LASTERROR)
+    return $LASTERROR
 }
 
 sub dump {
